summaryrefslogtreecommitdiffstats
path: root/sys/kern/uipc_proto.c
diff options
context:
space:
mode:
authorwollman <wollman@FreeBSD.org>1995-05-11 00:13:26 +0000
committerwollman <wollman@FreeBSD.org>1995-05-11 00:13:26 +0000
commit37660997fe63e18311e879f7d973edfeb03a28f5 (patch)
tree300274f99668c935a329a2380c568f8de35d4eb3 /sys/kern/uipc_proto.c
parent78ce3864de28cf6df1d35bae1167167384cc0d42 (diff)
downloadFreeBSD-src-37660997fe63e18311e879f7d973edfeb03a28f5.zip
FreeBSD-src-37660997fe63e18311e879f7d973edfeb03a28f5.tar.gz
Make networking domains drop-ins, through the magic of GNU ld. (Some day,
there may even be LKMs.) Also, change the internal name of `unixdomain' to `localdomain' since AF_LOCAL is now the preferred name of this family. Declare netisr correctly and in the right place.
Diffstat (limited to 'sys/kern/uipc_proto.c')
-rw-r--r--sys/kern/uipc_proto.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/sys/kern/uipc_proto.c b/sys/kern/uipc_proto.c
index b484737..0b72465 100644
--- a/sys/kern/uipc_proto.c
+++ b/sys/kern/uipc_proto.c
@@ -31,7 +31,7 @@
* SUCH DAMAGE.
*
* @(#)uipc_proto.c 8.1 (Berkeley) 6/10/93
- * $Id$
+ * $Id: uipc_proto.c,v 1.2 1994/08/02 07:43:04 davidg Exp $
*/
#include <sys/param.h>
@@ -41,20 +41,20 @@
#include <sys/mbuf.h>
/*
* Definitions of protocols supported in the UNIX domain.
*/
int uipc_usrreq(), raw_usrreq();
void raw_init(),raw_input(),raw_ctlinput();
-extern struct domain unixdomain; /* or at least forward */
+extern struct domain localdomain; /* or at least forward */
-struct protosw unixsw[] = {
-{ SOCK_STREAM, &unixdomain, 0, PR_CONNREQUIRED|PR_WANTRCVD|PR_RIGHTS,
+struct protosw localsw[] = {
+{ SOCK_STREAM, &localdomain, 0, PR_CONNREQUIRED|PR_WANTRCVD|PR_RIGHTS,
0, 0, 0, 0,
uipc_usrreq,
0, 0, 0, 0,
},
-{ SOCK_DGRAM, &unixdomain, 0, PR_ATOMIC|PR_ADDR|PR_RIGHTS,
+{ SOCK_DGRAM, &localdomain, 0, PR_ATOMIC|PR_ADDR|PR_RIGHTS,
0, 0, 0, 0,
uipc_usrreq,
0, 0, 0, 0,
@@ -68,6 +68,6 @@ struct protosw unixsw[] = {
int unp_externalize(), unp_dispose();
-struct domain unixdomain =
- { AF_UNIX, "unix", 0, unp_externalize, unp_dispose,
- unixsw, &unixsw[sizeof(unixsw)/sizeof(unixsw[0])] };
+struct domain localdomain =
+ { AF_LOCAL, "local", 0, unp_externalize, unp_dispose,
+ localsw, &localsw[sizeof(localsw)/sizeof(localsw[0])] };
OpenPOWER on IntegriCloud
@@ -41,20 +41,20 @@
#include <sys/mbuf.h>
/*
- * Definitions of protocols supported in the UNIX domain.
+ * Definitions of protocols supported in the LOCAL domain.
*/
int uipc_usrreq(), raw_usrreq();